# Changelog

## 6.6.0 (2025-02-07)

Full Changelog: [v6.5.0...v6.6.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v6.5.0...v6.6.0)

### Features

* misc ([8a01232](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/8a01232fbd2d5d2667c6712f5ef12f88587d3df2))

## 6.5.0 (2025-02-07)

Full Changelog: [v6.4.0...v6.5.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v6.4.0...v6.5.0)

### Features

* **api:** manual updates ([#37](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/37)) ([f65949d](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/f65949d9deca230bdf421010de6bfed3ef724266))
* **api:** manual updates ([#39](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/39)) ([c5fb131](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/c5fb1315204e24652bd2a767bfb83f6f821f6351))


### Chores

* publish OpenAPI spec ([#33](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/33)) ([541878f](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/541878ffbadd9eb1e4157e7713b835fdfb480959))
* publish OpenAPI spec ([#35](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/35)) ([35fa609](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/35fa609464475a87ff4b3fecd18e48f5c46938a0))
* publish OpenAPI spec ([#36](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/36)) ([63ccc5e](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/63ccc5e884a6d84d22688642420c113cdfde7886))
* publish OpenAPI spec ([#38](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/38)) ([40dcd2a](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/40dcd2a80f32781cbb569dcf8c1f58d24c37b5ce))
* publish OpenAPI spec ([#40](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/40)) ([3860160](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/38601609bb2713bddb9e3bc62b61f1b00c008c4c))

## 6.4.0 (2025-02-07)

Full Changelog: [v6.3.0...v6.4.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v6.3.0...v6.4.0)

### Features

* **client:** send `X-Stainless-Read-Timeout` header ([#27](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/27)) ([6cb8c2b](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/6cb8c2bf08161488e3eb19085fdf8ed0e3860ef0))
* feat(workers): support file path for flow creation ([b432765](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/b4327651a517383482cc8d9bac15047bdf33aa79))


### Chores

* **internal:** fix type traversing dictionary params ([#29](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/29)) ([98c3d80](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/98c3d80c2d1dba5cb5905a523f178adf885f7f49))
* **internal:** minor type handling changes ([#30](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/30)) ([a90618a](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/a90618a9fc43c178e0c98c930ecaa353b8a0758b))

## 6.3.0 (2025-02-05)

Full Changelog: [v6.2.1...v6.3.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v6.2.1...v6.3.0)

### Features

* **api:** manual updates ([#24](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/24)) ([72946fb](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/72946fb2cf30b7486171eea176760256b8fe9911))

## 6.2.1 (2025-02-05)

Full Changelog: [v6.2.0...v6.2.1](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v6.2.0...v6.2.1)

### Chores

* publish OpenAPI spec ([#21](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/21)) ([a885126](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/a88512682ec6d6aee9e35a0b40af9b04d03f9db3))

## 6.2.0 (2025-02-05)

Full Changelog: [v6.1.0...v6.2.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v6.1.0...v6.2.0)

### Features

* **api:** update via SDK Studio ([#18](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/18)) ([f7a6f44](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/f7a6f4438ac0019530e4fdcffb041605b12321f5))

## 6.1.0 (2025-02-05)

Full Changelog: [v6.0.1...v6.1.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v6.0.1...v6.1.0)

### Features

* **api:** update via SDK Studio ([#15](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/15)) ([d71f24c](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/d71f24cabfea30410d02bc1266555c887d2f6427))

## 6.0.1 (2025-02-05)

Full Changelog: [v0.1.0-alpha.1...v6.0.1](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v0.1.0-alpha.1...v6.0.1)

### Features

* **api:** update via SDK Studio ([#12](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/12)) ([2bc88a9](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/2bc88a97cf124d86dd2c1a397a6d0865441c884a))

## 0.1.0-alpha.1 (2025-02-04)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([#6](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/6)) ([2f9923b](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/2f9923bd9989785ee26457bf4d98644732ebd0f1))
* **api:** update via SDK Studio ([#9](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/9)) ([8380155](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/83801559f49536dba48d5bdefe312deef6ad9342))


### Chores

* go live ([#1](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/1)) ([839a103](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/839a10374ebfdcc038aeb4f98e66f9ed94f2de18))
* sync repo ([f502699](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/f502699a4803d8542b3681580a76500608b87900))
* update SDK settings ([#3](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/3)) ([66cb8ec](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/66cb8ec4118e474cb247ac45272396e5eff8bca3))
